Alibc4Platform class abstract

Inheritance
  • Object
  • PlatformInterface
  • Alibc4Platform
Implementers

Constructors

Alibc4Platform()
Constructs a Alibc4Platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkSession() → Future<Map?>
getPlatformVersion() → Future<String?>
getUserInfo() → Future<Map?>
getUtdid() → Future<Map?>
init() → Future<Map?>
login() → Future<Map?>
logout() → Future<Map?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
oauth(dynamic url) → Future<Map?>
openByBizCode(Map params) → Future<Map?>
openByUrl(Map params) → Future<Map?>
openCart(Map params) → Future<Map?>
setChannel(dynamic typeName, dynamic channelName) → Future<Map?>
setISVVersion(dynamic version) → Future<Map?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ Alibc4Platform
The default instance of Alibc4Platform to use.
getter/setter pair